use bevy::prelude::*;
use iyes_loopless::prelude::AppLooplessStateExt;

use crate::assets::AssetHandles;
use crate::system::flow::AppState;
use crate::system::utilities::TRANSPARENT;

#[derive(Component)]
pub struct Character;

pub fn create_debug_text(mut commands: Commands, assets: Res<AssetHandles>) {
	commands
		.spawn_bundle(NodeBundle {
			style: Style {
				position_type: PositionType::Absolute,
				size: Size::new(Val::Percent(100.0), Val::Percent(100.0)),
				justify_content: JustifyContent::Center,
				align_items: AlignItems::Center,
				..Default::default()
			},
			color: TRANSPARENT.into(),
			..Default::default()
		})
		.with_children(|children| {
			children
				.spawn_bundle(TextBundle {
					text: Text::from_section(
						" ",
						TextStyle {
							color: Color::WHITE,
							font_size: 48.0,
							font: assets.font("blocks"),
						},
					),
					..Default::default()
				})
				.insert(Character);
		});
}

pub fn set_last_character(
	input: Res<Input<KeyCode>>,
	mut query: Query<&mut Text, With<Character>>,
) {
	let last_key = input
		.get_just_released()
		.map(|key| format!("{:?}", key))
		.reduce(|acc, current| format!("{}, {}", acc, current));

	if let Some(last_key) = last_key {
		for mut text in &mut query {
			text.sections[0].value = last_key.clone();
		}
	}
}

pub struct DebugTextBundle;
impl Plugin for DebugTextBundle {
	fn build(&self, app: &mut App) {
		app.add_enter_system(AppState::Menu, create_debug_text)
			.add_system(set_last_character);
	}
}
